@@ -1,6 +1,5 @@
 #!/usr/bin/env python
-
-
+from __future__ import print_function
 import sys, tty, termios
 import time
 from stretch_body.hello_utils import *
@@ -17,7 +16,8 @@ small_rotate_rad=deg_to_rad(1.0)
 large_rotate_rad=deg_to_rad(10.0)
 
 b=base.Base()
-b.startup()
+if not b.startup():
+    exit()
 large_move_m=0.1
 small_move_m=large_move_m/8
 
@@ -47,24 +47,24 @@ def get_keystroke():
     return ch
 
 def menu():
-    print '--------------'
-    print 'm: menu'
-    print ''
-    print '1: rate slow'
-    print '2: rate default'
-    print '3: rate fast'
-    print '4: rate max'
-    print 'w: CW/CCW 90 deg'
-    print 'x: forward-> back 0.5m'
-    print 'y: spin at 22.5deg/s'
-    print ''
-    print 'f / b / l / r : small forward / back / left / right'
-    print 'F / B / L / R : large forward / back / left / right'
-    print 'o: freewheel'
-    print 'p: pretty print'
-    print 'q: quit'
-    print ''
-    print 'Input?'
+    print('--------------')
+    print('m: menu')
+    print('')
+    print('1: rate slow')
+    print('2: rate default')
+    print('3: rate fast')
+    print('4: rate max')
+    print('w: CW/CCW 90 deg')
+    print('x: forward-> back 0.5m')
+    print('y: spin at 22.5deg/s')
+    print('')
+    print('f / b / l / r : small forward / back / left / right')
+    print('F / B / L / R : large forward / back / left / right')
+    print('o: freewheel')
+    print('p: pretty print')
+    print('q: quit')
+    print('')
+    print('Input?')
 
 rate ='default'
 
@@ -79,7 +79,7 @@ try:
             #p.trigger_motor_sync()
             #time.sleep(0.1)
             b.pull_status()
-            #print '################################'
+            #print('################################'
             #b.pretty_print()
 
             if c=='p':
@@ -93,7 +93,7 @@ try:
             if c == '4':
                 rate = 'max'
             if c =='x':
-                    print 'Enter pause before starting motion (s)[10]'
+                    print('Enter pause before starting motion (s)[10]')
                     try:
                         x=float(raw_input())
                     except ValueError:
@@ -108,7 +108,7 @@ try:
                     p.trigger_motor_sync()
                     time.sleep(4.0)
             if c =='w':
-                print 'Enter pause before starting motion (s)[10]'
+                print('Enter pause before starting motion (s)[10]')
                 try:
                     x = float(raw_input())
                 except ValueError:
@@ -123,7 +123,7 @@ try:
                 p.trigger_motor_sync()
                 time.sleep(4.0)
             if c =='y':
-                print 'Enter pause before starting motion (s)[10]'
+                print('Enter pause before starting motion (s)[10]')
                 try:
                     x = float(raw_input())
                 except ValueError:
@@ -133,11 +133,11 @@ try:
                 b.push_command()
                 p.trigger_motor_sync()
                 ts=time.time()
-                print 'Starting 30s turn at 90deg/sec'
+                print('Starting 30s turn at 90deg/sec')
                 tsl=time.time()
                 while time.time()-ts<30.0:
                     b.pull_status()
-                    print 'DT:',time.time()-ts,'Vel (deg/s)', rad_to_deg(b.status['theta_vel'])
+                    print('DT:',time.time()-ts,'Vel (deg/s)', rad_to_deg(b.status['theta_vel']))
                     time.sleep(0.5)
                 b.set_rotational_velocity(v_r=0)
                 b.push_command()
