@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+from __future__ import print_function
 from stretch_body.dynamixel_XL430 import *
 import argparse
 import stretch_body.hello_utils as hu
@@ -7,7 +8,7 @@ hu.print_stretch_re_use()
 parser=argparse.ArgumentParser(description='Reboot all Dynamixel servos on robot')
 args=parser.parse_args()
 
-print '---- Rebooting Head ---- '
+print('---- Rebooting Head ---- ')
 for id in range(15):
     m = DynamixelXL430(id, '/dev/hello-dynamixel-head')
     m.startup()
@@ -16,7 +17,7 @@ for id in range(15):
     else:
         m.stop()
 
-print '---- Rebooting Wrist ---- '
+print('---- Rebooting Wrist ---- ')
 for id in range(15):
     m = DynamixelXL430(id, '/dev/hello-dynamixel-wrist')
     m.startup()
